summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvasellipse_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvasellipse_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvasellipse_imp.cpp62
1 files changed, 31 insertions, 31 deletions
diff --git a/kjsembed/qtbindings/qcanvasellipse_imp.cpp b/kjsembed/qtbindings/qcanvasellipse_imp.cpp
index 6c4fbff3..6d9311e7 100644
--- a/kjsembed/qtbindings/qcanvasellipse_imp.cpp
+++ b/kjsembed/qtbindings/qcanvasellipse_imp.cpp
@@ -1,12 +1,12 @@
-#include <qcstring.h>
-#include <qimage.h>
-#include <qpainter.h>
-#include <qpalette.h>
-#include <qpixmap.h>
-#include <qfont.h>
+#include <tqcstring.h>
+#include <tqimage.h>
+#include <tqpainter.h>
+#include <tqpalette.h>
+#include <tqpixmap.h>
+#include <tqfont.h>
#include <kjs/object.h>
@@ -15,7 +15,7 @@
#include <kjsembed/jsopaqueproxy.h>
#include <kjsembed/jsbinding.h>
-#include <qcanvas.h>
+#include <tqcanvas.h>
#include "qcanvasellipse_imp.h"
/**
@@ -43,7 +43,7 @@ void QCanvasEllipseImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &ob
};
int idx = 0;
- QCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -77,7 +77,7 @@ void QCanvasEllipseImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- QCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -90,25 +90,25 @@ void QCanvasEllipseImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a QCanvasEllipse pointer from an Object.
*/
-QCanvasEllipse *QCanvasEllipseImp::toQCanvasEllipse( KJS::Object &self )
+TQCanvasEllipse *QCanvasEllipseImp::toQCanvasEllipse( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- QObject *obj = ob->object();
+ TQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<QCanvasEllipse *>( obj );
+ return dynamic_cast<TQCanvasEllipse *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "QCanvasEllipse" )
+ if ( op->typeName() != "TQCanvasEllipse" )
return 0;
- return op->toNative<QCanvasEllipse>();
+ return op->toNative<TQCanvasEllipse>();
}
/**
@@ -134,7 +134,7 @@ KJS::Object QCanvasEllipseImp::construct( KJS::ExecState *exec, const KJS::List
break;
}
- QString msg = i18n("QCanvasEllipseCons has no constructor with id '%1'.").arg(id);
+ TQString msg = i18n("QCanvasEllipseCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -142,15 +142,15 @@ KJS::Object QCanvasEllipseImp::construct( KJS::ExecState *exec, const KJS::List
KJS::Object QCanvasEllipseImp::QCanvasEllipse_1( KJS::ExecState *exec, const KJS::List &args )
{
// Unsupported parameter QCanvas *
return KJS::Object();
- QCanvas * arg0; // Dummy
+ TQCanvas * arg0; // Dummy
- // We should now create an instance of the QCanvasEllipse object
+ // We should now create an instance of the TQCanvasEllipse object
- QCanvasEllipse *ret = new QCanvasEllipse(
+ TQCanvasEllipse *ret = new TQCanvasEllipse(
arg0 );
@@ -164,15 +164,15 @@ KJS::Object QCanvasEllipseImp::QCanvasEllipse_2( KJS::ExecState *exec, const KJS
int arg1 = extractInt(exec, args, 1);
// Unsupported parameter QCanvas *
return KJS::Object();
- QCanvas * arg2; // Dummy
+ TQCanvas * arg2; // Dummy
- // We should now create an instance of the QCanvasEllipse object
+ // We should now create an instance of the TQCanvasEllipse object
- QCanvasEllipse *ret = new QCanvasEllipse(
+ TQCanvasEllipse *ret = new TQCanvasEllipse(
arg0,
arg1,
@@ -192,15 +192,15 @@ KJS::Object QCanvasEllipseImp::QCanvasEllipse_3( KJS::ExecState *exec, const KJS
int arg3 = extractInt(exec, args, 3);
// Unsupported parameter QCanvas *
return KJS::Object();
- QCanvas * arg4; // Dummy
+ TQCanvas * arg4; // Dummy
- // We should now create an instance of the QCanvasEllipse object
+ // We should now create an instance of the TQCanvasEllipse object
- QCanvasEllipse *ret = new QCanvasEllipse(
+ TQCanvasEllipse *ret = new TQCanvasEllipse(
arg0,
arg1,
@@ -257,7 +257,7 @@ KJS::Value QCanvasEllipseImp::call( KJS::ExecState *exec, KJS::Object &self, con
break;
}
- QString msg = i18n( "QCanvasEllipseImp has no method with id '%1'." ).arg( id );
+ TQString msg = i18n( "QCanvasEllipseImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -337,10 +337,10 @@ KJS::Value QCanvasEllipseImp::areaPoints_11( KJS::ExecState *exec, KJS::Object &
KJS::Value QCanvasEllipseImp::collidesWith_12( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter const QCanvasItem *
return KJS::Value();
- const QCanvasItem * arg0; // Dummy
+ const TQCanvasItem * arg0; // Dummy
bool ret;
ret = instance->collidesWith(
@@ -90,25 +90,25 @@ void QCanvasEllipseImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a QCanvasEllipse pointer from an Object.
+ * Extract a TQCanvasEllipse pointer from an Object.
*/
@@ -142,15 +142,15 @@ KJS::Object QCanvasEllipseImp::construct( KJS::ExecState *exec, const KJS::List
KJS::Object QCanvasEllipseImp::QCanvasEllipse_1( KJS::ExecState *exec, const KJS::List &args )
{
- // Unsupported parameter QCanvas *
+ // Unsupported parameter TQCanvas *
return KJS::Object();
@@ -164,15 +164,15 @@ KJS::Object QCanvasEllipseImp::QCanvasEllipse_2( KJS::ExecState *exec, const KJS
int arg1 = extractInt(exec, args, 1);
- // Unsupported parameter QCanvas *
+ // Unsupported parameter TQCanvas *
return KJS::Object();
@@ -192,15 +192,15 @@ KJS::Object QCanvasEllipseImp::QCanvasEllipse_3( KJS::ExecState *exec, const KJS
int arg3 = extractInt(exec, args, 3);
- // Unsupported parameter QCanvas *
+ // Unsupported parameter TQCanvas *
return KJS::Object();
@@ -337,10 +337,10 @@ KJS::Value QCanvasEllipseImp::areaPoints_11( KJS::ExecState *exec, KJS::Object &
KJS::Value QCanvasEllipseImp::collidesWith_12( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter const QCanvasItem *
+ // Unsupported parameter const TQCanvasItem *
return KJS::Value();